@@ -4,25 +4,27 @@
 #'
 #' @param ... one or more MCMC objects
 #' @export
-#' @seealso \code{\link{bind_dimensions}}
+#' @seealso [bind_dimensions()]
 #' @examples
 #' bind_dimensions_n(mcmcr_example, mcmcr_example, mcmcr_example)
 bind_dimensions_n <- function(...) {
   UseMethod("bind_dimensions_n")
 }
 
-#' @describeIn bind_dimensions_n Binds multiple mcmcarray objects by their dimensions
 #' @export
 bind_dimensions_n.mcmcarray <- function(...) {
   x <- list(...)
 
-  if(!length(x)) err("one or more objects must be passed to bind_dimensions_n")
+  if (!length(x)) abort_chk("one or more objects must be passed to bind_dimensions_n")
 
-  if(length(x) == 1) return(x[[1]])
+  if (length(x) == 1) {
+    return(x[[1]])
+  }
 
   pdims <- lapply(x, pdims)
-  if(!all(vapply(pdims, identical, TRUE, pdims[[1]])))
-    err("all objects must have the same parameter dimensions")
+  if (!all(vapply(pdims, identical, TRUE, pdims[[1]]))) {
+    abort_chk("all objects must have the same parameter dimensions")
+  }
 
   along <- pdims(x[[1]])
   along <- length(along) + 1L
@@ -32,18 +34,20 @@ bind_dimensions_n.mcmcarray <- function(...) {
   x
 }
 
-#' @describeIn bind_dimensions_n Binds multiple mcmcr objects by their dimensions
 #' @export
 bind_dimensions_n.mcmcr <- function(...) {
   x <- list(...)
 
-  if(!length(x)) err("one or more objects must be passed to bind_dimensions_n")
+  if (!length(x)) abort_chk("one or more objects must be passed to bind_dimensions_n")
 
-  if(length(x) == 1) return(x[[1]])
+  if (length(x) == 1) {
+    return(x[[1]])
+  }
 
   pdims <- lapply(x, pdims)
-  if(!all(vapply(pdims, identical, TRUE, pdims[[1]])))
-    err("all objects must have the same parameter dimensions")
+  if (!all(vapply(pdims, identical, TRUE, pdims[[1]]))) {
+    abort_chk("all objects must have the same parameter dimensions")
+  }
 
   along <- pdims(x[[1]])
   along <- vapply(along, length, 1L) + 1L
