@@ -13,19 +13,19 @@ combine_samples_n <- function(x, ..., fun = mean) {
   UseMethod("combine_samples_n")
 }
 
-#' @describeIn combine_samples_n Combine samples of multiple MCMC objects
 #' @export
 combine_samples_n.default <- function(x, ..., fun = mean) {
-  if(!length(list(...))) return(x)
+  if (!length(list(...))) {
+    return(x)
+  }
   x <- bind_dimensions_n(x, ...)
   combine_dimensions(x, fun = fun)
 }
 
-#' @describeIn combine_samples_n Combine samples of a list of multiple MCMC objects
 #' @export
 combine_samples_n.list <- function(x, ..., fun = mean) {
-  check_list(x)
-  check_length(x)
+  chk_list(x)
+  chk_not_empty(x)
 
   names(x) <- NULL
   x$fun <- fun
