@@ -1,8 +1,10 @@
 #' @export
 summary.mcmcarray <- function(object, ...) {
-  summary <- list(estimates = estimates(object),
-                  nchains = nchains(object),
-                  niters = niters(object))
+  summary <- list(
+    estimates = estimates(object),
+    nchains = nchains(object),
+    niters = niters(object)
+  )
 
   class(summary) <- "summary.mcmcarray"
   summary
